//
// Created by Falko Alrik Schmidt on 26.09.23.
//

#ifndef UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H
#define UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H

#include <Wire.h>
#include "Ulm_Beginnable.h"
#include "MS5x.h"
#include "Ulm_GenericSensor.h"

/**
 * This class represents altitude sensors of type MS5607.
 * The pressure will be measured in mBar, temperature is in Celsius.
 *
 * @author Falko Schmidt
 * @since 1.0
 */
struct Ulm_MS5607_Sample {
    float temperature;  // Celsius
    float pressure;     // mBar
    float altitude;     // meters
};

class Ulm_MS5607 : MS5x, public Ulm_GenericSensor<struct Ulm_MS5607_Sample> {

public:
    /**
     * Constructor.
     * @param address the i2c address of MS5607 sensor.
     * @param aWire the i2c connection, defaults to {@code &Wire}.
     */
    explicit Ulm_MS5607(int8_t address);

    /**
     * Initializes the sensor.
     * @return {@code true} on success, {@code false} otherwise.
     */
    bool begin() override;

    bool sample(Ulm_MS5607_Sample &t) override;
};


#endif //UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H
